@@ -48,6 +48,7 @@ impl<W> Serializer<W> where W: Write {
         }
     }
 
+    /// Causes lines longer than 80 characters to be wrapped on word boundaries.
     pub fn wrap_long_lines(mut self, wrap: bool) -> Self {
         self.wrap_long_lines = wrap;
         self
@@ -122,9 +123,17 @@ impl<W> serde::Serializer for Serializer<W> where W: Write {
     }
 }
 
+#[doc(hidden)]
+#[deprecated = "This was published by accident and should not be used. It'll be removed without replacement."]
+pub use internal::NonSeqSerializer;
+
+mod internal {
+use super::*;
+
+#[doc(hidden)]
 pub struct NonSeqSerializer<Writer: Write> {
-    writer: Writer,
-    wrap_long_lines: bool,
+    pub(crate) writer: Writer,
+    pub(crate) wrap_long_lines: bool,
 }
 
 impl<W> serde::Serializer for NonSeqSerializer<W> where W: Write {
@@ -187,7 +196,12 @@ impl<W> serde::Serializer for NonSeqSerializer<W> where W: Write {
         fn serialize_struct_variant(self, name: &'static str, variant_index: u32, variant: &'static str, len: usize) -> Result<Self::SerializeStructVariant>;
     }
 }
+}
 
+/// Serializer used for serializing sequences of records.
+///
+/// This type is internal and should not be used directly. If you need to refer to it it's best to use
+/// `Serializer::SerializeSeq`.
 pub struct SeqSerializer<Writer: Write> {
     output: Writer,
     wrap_long_lines: bool,
@@ -202,7 +216,7 @@ impl<W> ser::SerializeSeq for SeqSerializer<W> where W: Write {
         if !self.is_empty {
             writeln!(self.output).map_err(Error::failed_write)?;
         }
-        value.serialize(NonSeqSerializer { writer: &mut self.output, wrap_long_lines: self.wrap_long_lines })
+        value.serialize(internal::NonSeqSerializer { writer: &mut self.output, wrap_long_lines: self.wrap_long_lines })
     }
 
     fn end(self) -> Result<Self::Ok, Self::Error> {
